Editor Test: LinkDialog Plugin

1. The LinkDialog plugin is an 'example' style plugin that shows how to insert basic web links as well as image tags. This plugin is intended to guide users in writing their own, more complex, link and image handlers while still providing useful function.

This is an example link in the page.

Editor with `allowUnsafeHtml` set to `true`

This editor will allow unrestricted HTML in the Description field of links

Editor with custom `linkFilter` function

Links created in this editor will always have a description of "Filtered Value", which is the value returned by the custom `linkFilter` function.

RTL Editor:

1. The LinkDialog plugin is an 'example' style plugin that shows how to insert basic web links as well as image tags. This plugin is intended to guide users in writing their own, more complex, link and image handlers while still providing useful function.

This is an example link in the page.